@@ -4,11 +4,11 @@
 
 ;; Author: Ryan C. Thompson
 ;; URL: https://github.com/DarwinAwardWinner/ido-ubiquitous
-;; Version: 3.14
+;; Version: 3.16
 ;; Created: 2011-09-01
 ;; Keywords: convenience, completion, ido
 ;; EmacsWiki: InteractivelyDoThings
-;; Package-Requires: ((emacs "24.1") (ido-completing-read+ "3.14") (cl-lib "0.5"))
+;; Package-Requires: ((emacs "24.1") (ido-completing-read+ "3.16") (cl-lib "0.5"))
 ;; Filename: ido-ubiquitous.el
 
 ;; This file is NOT part of GNU Emacs.
@@ -69,7 +69,7 @@
 ;;
 ;;; Code:
 
-(defconst ido-ubiquitous-version "3.14"
+(defconst ido-ubiquitous-version "3.16"
   "Currently running version of ido-ubiquitous.
 
 Note that when you update ido-ubiquitous, this variable may not
@@ -102,11 +102,9 @@ Debug info is printed to the *Messages* buffer."
   :global t
   :group 'ido-ubiquitous)
 
-;; Defined as a macro for efficiency (args are not evaluated unless
-;; debug mode is on)
-(defmacro ido-ubiquitous--debug-message (format-string &rest args)
-  `(when ido-ubiquitous-debug-mode
-     (message (concat "ido-ubiquitous: " ,format-string) ,@args)))
+(defun ido-ubiquitous--debug-message (format-string &rest args)
+  (when ido-ubiquitous-debug-mode
+     (apply #'message (concat "ido-ubiquitous: " format-string) args)))
 
 (defun ido-ubiquitous--explain-fallback (arg)
   ;; This function accepts a string, or an ido-ubiquitous-fallback
@@ -114,7 +112,7 @@ Debug info is printed to the *Messages* buffer."
   (when ido-ubiquitous-debug-mode
     (when (and (listp arg)
                (eq (car arg) 'ido-ubiquitous-fallback))
-      (setq arg (cdr arg)))
+      (setq arg (cadr arg)))
     (ido-ubiquitous--debug-message "Falling back to `%s' because %s."
                                    ido-cr+-fallback-function arg)))
 
@@ -333,8 +331,6 @@ using overrides and disable it for everything else."
     (enable exact "find-tag")
     ;; https://github.com/DarwinAwardWinner/ido-ubiquitous/issues/89
     (enable prefix "etags-select-")
-    ;; https://github.com/DarwinAwardWinner/ido-ubiquitous/issues/110
-    (enable regexp "\\`describe-\\(function\\|variable\\)\\'")
     ) ; Close paren on separate line for better VC diffs
   "Default value of `ido-ubiquitous-command-overrides'.
 
@@ -366,6 +362,8 @@ You can restore these using the command `ido-ubiquitous-restore-default-override
     (enable exact "imenu--completion-buffer")
     ;; https://github.com/DarwinAwardWinner/ido-ubiquitous/issues/74
     (enable-old exact "auto-insert")
+    ;; https://github.com/DarwinAwardWinner/ido-ubiquitous/issues/116
+    (enable exact "project--completing-read-strict")
     ) ; Close paren on separate line for better VC diffs
   "Default value of `ido-ubiquitous-function-overrides'.
 
@@ -667,7 +665,7 @@ completion for them."
               ;; If ido-ubiquitous is disabled this time, fall back
               (when (eq ido-ubiquitous-active-state 'disable)
                 (signal 'ido-ubiquitous-fallback
-                        "`ido-ubiquitous-active-state' is `disable'"))
+                        '("`ido-ubiquitous-active-state' is `disable'")))
               ;; Handle a collection that is a function: either expand
               ;; completion list now or fall back
               (when (functionp collection)
@@ -679,15 +677,20 @@ completion for them."
                           ;; so it now becomes redundant.
                           predicate nil)
                   (signal 'ido-ubiquitous-fallback
-                          "COLLECTION is a function and there is no override")))
+                          '("COLLECTION is a function and there is no override"))))
               (let ((ido-ubiquitous-enable-next-call t))
                 (ido-completing-read+
                  prompt collection predicate require-match
                  initial-input hist def inherit-input-method)))
+          ;; Pass through any known fallback signals to the outer
+          ;; `condition-case'
+          (ido-ubiquitous-fallback
+           (signal (car err) (cdr err)))
+          ;; Convert any other error into a fallback signal.
           (error
            (signal 'ido-ubiquitous-fallback
-                   (format "ido-ubiquitous encountered an unexpected error: %S"
-                           err))))
+                   (list (format "ido-ubiquitous encountered an unexpected error: %S"
+                                 err)))))
       ;; Handler for ido-ubiquitous-fallback signal
       (ido-ubiquitous-fallback
        (ido-ubiquitous--explain-fallback sig)
